==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/app/controllers/spirit_hub/application_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class ApplicationController < ActionController::Base
    include Pundit::Authorization
    protect_from_forgery with: :exception
    before_action :try_to_set_user_from_token
    before_action :authenticate_user!
    before_action :set_turbo_actions
    before_action :set_locale

    after_action :verify_authorized
    after_action :verify_policy_scoped

    rescue_from StandardError, with: :server_error unless Rails.env.development?
    rescue_from Pundit::NotAuthorizedError, with: :unauthorized_user
    rescue_from Mongoid::Errors::DocumentNotFound, with: :not_found_error

    def authenticate_user!
      return redirect_to('/users/sign_in', alert: 'You need to sign up before continuing.') unless user_signed_in?

      @user = current_user
    end

    def auth_user_token
      request.headers['X-auth-user-token']
    end

    def set_user_favorites
      @user_favorites = Favorite.where(user_id: @user.id).pluck(:tagset_id).flatten.uniq.compact
    end

    private

    def set_locale
      I18n.locale = :fr
    end

    def set_turbo_actions
      @turbo_actions = []
    end

    def update_flash_message
      @turbo_actions << turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
    end

    def try_to_set_user_from_token
      return unless auth_user_token

      user = User.find_by(authentication_token: auth_user_token)

      return unless user && user != warden.user

      warden.set_user(user)
    end

    def route_controller_from_referer
      referer = request.referer
      return nil if referer.blank?

      begin
        Rails.application.routes.recognize_path(URI(referer).path)[:controller]
      rescue ActionController::RoutingError
        nil
      end
    end

    def formatted_params(*permitted_keys)
      params.permit(*permitted_keys)
            .to_h
            .merge(current_user: @user)
            .transform_values(&:presence)
            .compact
            .symbolize_keys
    end

    def send_doc_file(doc, file, mode = 'inline') # rubocop:disable Metrics/AbcSize
      file ||= doc.file
      if doc && file
        Rails.logger.debug "STREAMING WITH ENUM #{file.class}"
        response.headers['ETag'] = file.md5
        response.headers['Expires'] = 1.day.from_now.httpdate
        response.headers['Content-Disposition'] = "#{mode}; filename=#{doc.clean_name}"
        response.headers['Content-Type'] = doc.content_type
        response.headers['Content-Filename'] = doc.clean_name
        response.headers['X-Accel-Buffering'] = 'no'
        response.headers['Cache-Control'] = 'no-cache'
        response.headers.delete('Content-Length')

        send_data(file.data, disposition: mode, stream: true, filename: doc.clean_name, url_based_filename: doc.clean_name, type: doc.content_type)
      elsif mode == 'inline'
        response.headers['Expires'] = 1.year.from_now.httpdate
        send_file("#{Rails.root}/app/assets/images/no_preview_image.png")
      else
        render body: nil
      end
    end

    def send_files_as_zip(docs, filename)
      # thanks to fring/zipline
      body = Doc.as_zip(docs)
      response.headers['Content-Disposition'] = "attachment; filename=\"#{filename.gsub '"', '\"'}\""
      response.headers['Content-Type'] = Mime::Type.lookup_by_extension('zip').to_s
      response.headers['X-Accel-Buffering'] = 'no'
      response.headers['Last-Modified'] = Time.now.httpdate
      response.headers['Cache-Control'] = 'no-cache'

      response.sending_file = true
      response.cache_control[:public] ||= false

      self.response_body = body
    end

    def policy_class
      self.class.name.gsub('Controller', 'Policy').constantize
    end

    def policy_scope_class
      "#{policy_class}::Scope".constantize
    end

    def server_error(exception)
      LogError.create(
        message: exception.to_s,
        user_info: @user.email,
        referer_url: request.referer,
        target_url: request.url,
        class_name: exception.class.to_s,
        user_agent: request.user_agent,
        params: request.params,
        trace: exception.backtrace.join("\n"),
        app_name: Rails.application.class.module_parent_name
      )

      respond_with_error(
        error_message: 'Une erreur technique est survenue',
        error_status: :internal_server_error
      )
    end

    def unauthorized_user
      respond_with_error(
        error_message: 'Vous n\'avez pas les droits pour effectuer cette action',
        error_status: :forbidden
      )
    end

    def not_found_error
      respond_with_error(
        error_message: 'L\'élement n\'a pas été trouvé',
        error_status: :not_found
      )
    end

    def respond_with_error(error_message:, error_status:)
      skip_authorization
      skip_policy_scope

      http_status_code = error_status.is_a?(Symbol) ? Rack::Utils::SYMBOL_TO_STATUS_CODE[error_status] : error_status

      respond_to do |format|
        format.html { render 'spirit_hub/errors/error_page', status: :ok, locals: { error_message:, http_status_code: } }
        format.turbo_stream do
          flash.now[:alert] = error_message
          render turbo_stream: [
            turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
          ], status: error_status
        end
      end
    end
  end
end

==> spirit_hub-0.1.1.25.tar.gz: spirit_hub-0.1.1.25/app/controllers/spirit_hub/application_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class ApplicationController < ActionController::Base
    include Pundit::Authorization
    protect_from_forgery with: :exception
    before_action :try_to_set_user_from_token
    before_action :authenticate_user!
    before_action :set_turbo_actions
    before_action :set_locale

    after_action :verify_authorized
    after_action :verify_policy_scoped

    rescue_from StandardError, with: :server_error unless Rails.env.development?
    rescue_from Pundit::NotAuthorizedError, with: :unauthorized_user
    rescue_from Mongoid::Errors::DocumentNotFound, with: :not_found_error

    def authenticate_user!
      return redirect_to('/users/sign_in', alert: 'You need to sign up before continuing.') unless user_signed_in?

      @user = current_user
    end

    def auth_user_token
      request.headers['X-auth-user-token']
    end

    def set_user_favorite_tagset_ids
      @user_favorite_tagset_ids = @user.favorite_tagset_ids
    end

    private

    def set_locale
      I18n.locale = :fr
    end

    def set_turbo_actions
      @turbo_actions = []
    end

    def update_flash_message
      @turbo_actions << turbo_stream.prepend(:flash_messages, FlashMessagesComponent.new(flash))
    end

    def try_to_set_user_from_token
      return unless auth_user_token

      user = User.find_by(authentication_token: auth_user_token)

      return unless user && user != warden.user

      warden.set_user(user)
    end

    def route_controller_from_referer
      referer = request.referer
      return nil if referer.blank?

      begin
        Rails.application.routes.recognize_path(URI(referer).path)[:controller]
      rescue ActionController::RoutingError
        nil
      end
    end

    def formatted_params(*permitted_keys)
      params.permit(*permitted_keys)
            .to_h
            .merge(current_user: @user)
            .transform_values(&:presence)
            .compact
            .symbolize_keys
    end

    def send_doc_file(doc, file, mode = 'inline') # rubocop:disable Metrics/AbcSize
      file ||= doc.file
      if doc && file
        Rails.logger.debug "STREAMING WITH ENUM #{file.class}"
        response.headers['ETag'] = file.md5
        response.headers['Expires'] = 1.day.from_now.httpdate
        response.headers['Content-Disposition'] = "#{mode}; filename=#{doc.clean_name}"
        response.headers['Content-Type'] = doc.content_type
        response.headers['Content-Filename'] = doc.clean_name
        response.headers['X-Accel-Buffering'] = 'no'
        response.headers['Cache-Control'] = 'no-cache'
        response.headers.delete('Content-Length')

        send_data(file.data, disposition: mode, stream: true, filename: doc.clean_name, url_based_filename: doc.clean_name, type: doc.content_type)
      elsif mode == 'inline'
        response.headers['Expires'] = 1.year.from_now.httpdate
        send_file("#{Rails.root}/app/assets/images/no_preview_image.png")
      else
        render body: nil
      end
    end

    def send_files_as_zip(docs, filename)
      # thanks to fring/zipline
      body = Doc.as_zip(docs)
      response.headers['Content-Disposition'] = "attachment; filename=\"#{filename.gsub '"', '\"'}\""
      response.headers['Content-Type'] = Mime::Type.lookup_by_extension('zip').to_s
      response.headers['X-Accel-Buffering'] = 'no'
      response.headers['Last-Modified'] = Time.now.httpdate
      response.headers['Cache-Control'] = 'no-cache'

      response.sending_file = true
      response.cache_control[:public] ||= false

      self.response_body = body
    end

    def policy_class
      self.class.name.gsub('Controller', 'Policy').constantize
    end

    def policy_scope_class
      "#{policy_class}::Scope".constantize
    end

    def server_error(exception)
      LogError.create(
        message: exception.to_s,
        user_info: @user.email,
        referer_url: request.referer,
        target_url: request.url,
        class_name: exception.class.to_s,
        user_agent: request.user_agent,
        params: request.params,
        trace: exception.backtrace.join("\n"),
        app_name: Rails.application.class.module_parent_name
      )

      respond_with_error(
        error_message: 'Une erreur technique est survenue',
        error_status: :internal_server_error
      )
    end

    def unauthorized_user
      respond_with_error(
        error_message: 'Vous n\'avez pas les droits pour effectuer cette action',
        error_status: :forbidden
      )
    end

    def not_found_error
      respond_with_error(
        error_message: 'L\'élement n\'a pas été trouvé',
        error_status: :not_found
      )
    end

    def respond_with_error(error_message:, error_status:)
      skip_authorization
      skip_policy_scope

      http_status_code = error_status.is_a?(Symbol) ? Rack::Utils::SYMBOL_TO_STATUS_CODE[error_status] : error_status

      respond_to do |format|
        format.html { render 'spirit_hub/errors/error_page', status: :ok, locals: { error_message:, http_status_code: } }
        format.turbo_stream do
          flash.now[:alert] = error_message
          render turbo_stream: [
            turbo_stream.prepend(:flash_messages, FlashMessagesComponent.new(flash))
          ], status: error_status
        end
      end
    end

    def controller_name
      self.class.name.demodulize.sub('Controller', '').underscore.downcase
    end

    def set_columns(force_controller_name = nil)
      @all_columns, @user_column_names, @columns = SpiritHub::UserDisplayOptionHelper.new(@user).get_columns_for(force_controller_name || controller_name)
    end

    def set_view_type(force_controller_name = nil)
      @view_type = @user.display_option.view_types&.dig(force_controller_name || controller_name) || 'table'
    end

    def flash_message_with_link(message:, link_url:, link_text:)
      new_message = "#{message} "
      new_message << view_context.link_to(link_text, link_url,
                                          data: { turbo_frame: :app_content, turbo_action: :advance },
                                          class: 'underline hover:text-text-primary')
      new_message.html_safe
    end
  end
end
